# libraries
library(dplyr)

# set wd
setwd("Drive/folderpath/")

# read data
dat.df <- read.csv("./Data_raw/AgriDiv_data.csv")

# SA and SR
for(i in unique(dat.df$Land_use)){
  for(j in unique(dat.df$Diversity_metric_type)){
    dat.df[which(dat.df$Land_use == i & dat.df$Diversity_metric_type == j), "n_transform"] <- nrow(dat.df[which(dat.df$Land_use == i & dat.df$Diversity_metric_type == j), ])
  }
}
rm(i, j)

dat.df$lnRR <- log((((dat.df$Diversity_value / dat.df$Diversity_value_ref) * (dat.df$n_transform - 1) + 0.5)) / dat.df$n_transform)
dat.df[which(dat.df$Diversity_value_ref == 0), "lnRR"] <- log(2 * dat.df[which(dat.df$Diversity_value_ref == 0), "n_transform"])
dat.df[which(dat.df$Diversity_value == 0 & dat.df$Diversity_value_ref == 0), "lnRR"] <- log(((dat.df[which(dat.df$Diversity_value == 0 & dat.df$Diversity_value_ref == 0), "n_transform"] - 1)+ 0.5) / dat.df[which(dat.df$Diversity_value == 0 & dat.df$Diversity_value_ref == 0), "n_transform"])

dat.df$weight <- 1
dat.df[which(dat.df$Diversity_value == 0 | dat.df$Diversity_value_ref == 0), "weight"] <- log(0.5) / log(1 / dat.df[which(dat.df$Diversity_value == 0 | dat.df$Diversity_value_ref == 0), "n_transform"])

# MSA
msa.df <- dat.df
msa.df <- msa.df[which(msa.df$Diversity_metric_type == "Abundance" & msa.df$Diversity_value_ref > 0), ]
msa.df$SSS_ID <- paste(msa.df$Source_ID, msa.df$Study_ID, msa.df$Site_ID, sep = "_")
msa.df$RR_s <- msa.df$Diversity_value / msa.df$Diversity_value_ref
msa.df$RR_s[which(msa.df$RR_s > 1)] <- 1
msa.df <- msa.df[which(!is.na(msa.df$RR_s)), ]

msa.df <- group_by(msa.df, SSS_ID)
msa.df <- summarise(msa.df, rid = head(rid, 1), 
                    rid = head(rid, 1), 
                    Reference = head(Reference, 1),
                    Reference_yr = head(Reference_yr, 1),
                    DOI = head(DOI, 1),
                    Latitude = head(Latitude, 1),
                    Longitude = head(Longitude, 1),
                    Data_collection_start_yr = head(Data_collection_start_yr, 1),
                    Data_collection_end_yr = head(Data_collection_end_yr, 1),
                    Source_ID = head(Source_ID, 1), 
                    Study_ID = head(Study_ID, 1), 
                    Site_ID = head(Site_ID, 1), 
                    Land_use = head(Land_use, 1), 
                    Natural_vegetation_type = head(Natural_vegetation_type, 1),
                    Natural_elements = head(Natural_elements, 1), 
                    Diversification = head(Diversification, 1), 
                    Rotation = head(Rotation, 1), 
                    MSA_site = mean(RR_s, na.rm = T),
                    n_species = length(Diversity_value))

msa.df$n <- NA
msa.df$n[which(msa.df$Land_use == "Cropland")] <- length(which(msa.df$Land_use == "Cropland"))
msa.df$n[which(msa.df$Land_use == "Forest_plantation")] <- length(which(msa.df$Land_use == "Forest_plantation"))

msa.df$Source_ID <- as.factor(msa.df$Source_ID)
msa.df$Study_ID <- as.factor(msa.df$Study_ID)
msa.df$Diversification <- as.factor(msa.df$Diversification)
msa.df$Diversification <- relevel(msa.df$Diversification, ref = "No_crop_diversification")

for(i in unique(msa.df$Land_use)){
    msa.df[which(msa.df$Land_use == i), "n_transform"] <- nrow(msa.df[which(msa.df$Land_use == i), ])
}
rm(i)

msa.df$MSA_site <- (msa.df$MSA_site * (msa.df$n_transform - 1) + 0.5) / msa.df$n_transform
msa.df$weight <- sqrt(msa.df$n_species)

# write data
write.csv(dat.df, file = "./Data_derived/RIA_RSR_effect_sizes.csv", row.names = F)
write.csv(msa.df, file = "./Data_derived/MSA_effect_sizes.csv", row.names = F)
