# libraries
library(lmerTest)
library(dplyr)
library(MuMIn)

# set wd
setwd("Drive/folderpath/")

# Read data ---------------------------------------------------------------

dat.df <- read.csv("./data_derived/RIA_RSR_effect_sizes.csv")
msa.df <- read.csv("./data_derived/MSA_effect_sizes.csv")

dat.df <- filter(dat.df, Land_use %in% c("Cropland", "Forest_plantation"), !is.na(Natural_elements), !is.na(Diversification))
ria.df <- filter(dat.df, Diversity_metric_type == "Abundance")
rsr.df <- filter(dat.df, Diversity_metric_type == "Richness")
msa.df <- filter(msa.df, Land_use %in% c("Cropland", "Forest_plantation"))
msa.df <- mutate(msa.df, ltMSA = log(MSA_site / (1 - MSA_site)))

rm(dat.df)


# Regression models -------------------------------------------------------

ria_c.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Cropland"), REML = T)
ria_f.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Forest_plantation"), REML = T)
rsr_c.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Cropland"), REML = T)
rsr_f.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Forest_plantation"), REML = T)
msa_c.lm <- lmer(ltMSA ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Cropland"), REML = T)
msa_f.lm <- lmer(ltMSA ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Forest_plantation"), REML = T)

# Tests -------------------------------------------------------------------

# Individual species abundance
## Cropland
summary(ria_c.lm)
confint(ria_c.lm, method = "boot", nsim = 1000)
r.squaredGLMM(ria_c.lm)

## Forest plantation
summary(ria_f.lm)
confint(ria_f.lm, method = "boot", nsim = 1000)
r.squaredGLMM(ria_f.lm)

# Species richness
## Cropland
summary(rsr_c.lm)
confint(rsr_c.lm, method = "boot", nsim = 1000)
r.squaredGLMM(rsr_c.lm)

## Forest plantation
summary(rsr_f.lm)
confint(rsr_f.lm, method = "boot", nsim = 1000)
r.squaredGLMM(rsr_f.lm)

# Assemblage intactness
## Cropland
summary(msa_c.lm)
confint(msa_c.lm, method = "boot", nsim = 1000)
r.squaredGLMM(msa_c.lm)

## Forest plantation
summary(msa_f.lm)
confint(msa_f.lm, method = "boot", nsim = 1000)
r.squaredGLMM(msa_f.lm)