# libraries
library(lmerTest)
library(MuMIn)
library(dplyr)

# set wd
setwd("Drive/folderpath/")


# Read data ---------------------------------------------------------------

dat.df <- read.csv("./Data_derived/RIA_RSR_effect_sizes.csv")
msa.df <- read.csv("./Data_derived/MSA_effect_sizes.csv")
sp.df <- read.csv("./Data_raw/Species_data.csv")
lc.df <- read.csv("./Data_raw/Landscape_data.csv")

dat.df <- filter(dat.df, Land_use %in% c("Cropland", "Forest_plantation"), !is.na(Natural_elements), !is.na(Diversification))
dat.df <- mutate(dat.df, Year = coalesce(Data_collection_end_yr, Reference_yr))

ria.df <- filter(dat.df, Diversity_metric_type == "Abundance")
ria.df <- left_join(ria.df, sp.df)
ria.df <- mutate(ria.df, Body_mass = log(Body_mass), Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
ria.df <- left_join(ria.df, dplyr::select(lc.df, -ID))
ria.df <- filter(ria.df, !is.na(Habitat_breadth), !is.na(Origin), !is.na(Diet_diversity), !is.na(Body_mass))

rsr.df <- filter(dat.df, Diversity_metric_type == "Richness")
rsr.df <- left_join(rsr.df, dplyr::select(lc.df, -ID))
rsr.df <- mutate(rsr.df, Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)

msa.df <- filter(msa.df, Land_use %in% c("Cropland", "Forest_plantation"))
msa.df <- mutate(msa.df, ltMSA = log(MSA_site / (1 - MSA_site)),
                 Year = coalesce(Data_collection_end_yr, Reference_yr),
                 Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
msa.df <- left_join(msa.df, select(lc.df, -ID))

rm(dat.df, sp.df, lc.df)


# Individual species abundance --------------------------------------------

# cropland
ria_c.df <- filter(ria.df, Land_use == "Cropland")

## main
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_main.csv", row.names = F)

## Habitat breadth
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_habitat_breadth.csv", row.names = F)

## Diet dieversity
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diet_diversity + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_diet_diversity.csv", row.names = F)

## Origin
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Origin + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_origin.csv", row.names = F)

## Body mass
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Body_mass + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_body_mass.csv", row.names = F)

## Latitude
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Latitude_abs + Natural_elements * Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_latitude.csv", row.names = F)

## Landscape context
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_landscape_context.csv", row.names = F)

## Natural habitat
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_cropland_natural_habitat.csv", row.names = F)


# Forest plantations
ria_f.df <- filter(ria.df, Land_use == "Forest_plantation")

## main
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_main.csv", row.names = F)

## habitat breadth
ms.df <- dredge(lmer(lnRR ~ Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_habitat_diversity.csv", row.names = F)

## Diet diversity
ms.df <- dredge(lmer(lnRR ~ Diet_diversity + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
#ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diversification + Natural_elements * Diet_diversity + Diversification : Diet_diversity + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_diet_diversity.csv", row.names = F)

## Origin
ms.df <- dredge(lmer(lnRR ~ Origin + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_origin.csv", row.names = F)

## Body mass
ms.df <- dredge(lmer(lnRR ~ Body_mass + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_body_mass.csv", row.names = F)

## Latitude
ms.df <- dredge(lmer(lnRR ~ Latitude_abs + Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_latitude.csv", row.names = F)

## Landscape context
ms.df <- dredge(lmer(lnRR ~ Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_landscape_context.csv", row.names = F)

## Natural habitat
ms.df <- dredge(lmer(lnRR ~ Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RIA_forest_plantation_natural_habitat.csv", row.names = F)


# Species richness --------------------------------------------------------

# cropland
rsr_c.df <- filter(rsr.df, Land_use == "Cropland")

## main
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = rsr_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_cropland_main.csv", row.names = F)

## latitude
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Latitude_abs + Natural_elements * Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = rsr_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_cropland_latitude.csv", row.names = F)

## landscape context
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = rsr_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_richness_cropland_landscape_context.csv", row.names = F)

## Natural habitat
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = rsr_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_cropland_natural_habitat.csv", row.names = F)


# forest plantation
rsr_f.df <- filter(rsr.df, Land_use == "Forest_plantation")

## main
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_forest_plantation_main.csv", row.names = F)

## latitude
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Latitude_abs + Natural_elements * Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_forest_plantation_latitude.csv", row.names = F)

## landscape context
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_forest_plantation_landscape_context.csv", row.names = F)

## natural habitat
ms.df <- dredge(lmer(lnRR ~ Natural_elements * Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_RSR_forest_plantation_natural_habitat.csv", row.names = F)


# MSA ---------------------------------------------------------------------

# cropland
msa_c.df <- filter(msa.df, Land_use == "Cropland")

## main
ms.df <- dredge(lmer(ltMSA ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_cropland_main.csv", row.names = F)

## latitude
ms.df <- dredge(lmer(ltMSA ~ Natural_elements * Latitude_abs + Natural_elements * Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_cropland_latitude.csv", row.names = F)

## landscape context
ms.df <- dredge(lmer(ltMSA ~ Natural_elements * Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_cropland_landscape_context.csv", row.names = F)

## natural habitat
ms.df <- dredge(lmer(ltMSA ~ Natural_elements * Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
write.csv(ms.df, "./03_Model_selection_MSA_cropland_natural_habitat.csv", row.names = F)


## forest plantation
msa_f.df <- filter(msa.df, Land_use == "Forest_plantation")

## main
ms.df <- dredge(lmer(ltMSA ~ Natural_elements * Diversification + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_forest_plantation_main.csv", row.names = F)

## latitude
ms.df <- dredge(lmer(ltMSA ~ Diversification * Latitude_abs + Diversification * Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_forest_plantation_latitude.csv", row.names = F)

## landscape context
ms.df <- dredge(lmer(ltMSA ~ Diversification * Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_forest_plantation_landscape_context.csv", row.names = F)

## natural habitat
ms.df <- dredge(lmer(ltMSA ~ Diversification * Natural_vegetation_type + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = F, na.action = na.fail))
ms.df <- rename(ms.df, Intercept = `(Intercept)`)
#write.csv(ms.df, "./Data_derived/03_Model_selection_MSA_forest_plantation_natural_habitat.csv", row.names = F)