# libraries
library(lmerTest)
library(MuMIn)
library(dplyr)
library(stringr)

# set wd
setwd("Drive/folderpath/")


# Function ----------------------------------------------------------------

test.f <- function(null_mod, best_mod){
  print("Omnibus test:")
  print(anova(null_mod, best_mod))
  print("")
  print("R-squared")
  print(r.squaredGLMM(best_mod))
  print("")
  print("F test")
  print(anova(best_mod))
}


# Read data ---------------------------------------------------------------

dat.df <- read.csv("./Data_derived/RIA_RSR_effect_sizes.csv")
msa.df <- read.csv("./Data_derived/MSA_effect_sizes.csv")
sp.df <- read.csv("./Data_raw/Species_data.csv")
lc.df <- read.csv("./Data_raw/Landscape_data.csv")

dat.df <- filter(dat.df, Land_use %in% c("Cropland", "Forest_plantation"), !is.na(Natural_elements), !is.na(Diversification))
dat.df <- mutate(dat.df, Year = coalesce(Data_collection_end_yr, Reference_yr))

ria.df <- filter(dat.df, Diversity_metric_type == "Abundance")
ria.df <- left_join(ria.df, sp.df)
ria.df <- mutate(ria.df, Body_mass = log(Body_mass), Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
ria.df <- left_join(ria.df, dplyr::select(lc.df, -ID))
ria.df <- filter(ria.df, !is.na(Habitat_breadth), !is.na(Origin), !is.na(Diet_diversity), !is.na(Body_mass))

rsr.df <- filter(dat.df, Diversity_metric_type == "Richness")
rsr.df <- left_join(rsr.df, dplyr::select(lc.df, -ID))
rsr.df <- mutate(rsr.df, Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)

msa.df <- filter(msa.df, Land_use %in% c("Cropland", "Forest_plantation"))
msa.df <- mutate(msa.df, ltMSA = log(MSA_site / (1 - MSA_site)),
                 Year = coalesce(Data_collection_end_yr, Reference_yr),
                 Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
msa.df <- left_join(msa.df, select(lc.df, -ID))

rm(dat.df, sp.df, lc.df)


# Abundance ---------------------------------------------------------------

# Cropland
ria_c_0.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Cropland"), REML = T)

## Main
ria_c_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Cropland"), REML = T)
test.f(ria_c_0.lm, ria_c_m.lm)
nrow(filter(ria.df, Land_use == "Cropland"))

## Habitat breadth
ria_c_h.lm <- lmer(lnRR ~ Natural_elements + Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Cropland"), REML = T)
test.f(ria_c_0.lm, ria_c_h.lm)
nrow(filter(ria.df, Land_use == "Cropland"))

# Forest plantation
ria_f_0.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Forest_plantation"), REML = T)

## Main
test.f(ria_f_0.lm, ria_f_0.lm)
nrow(filter(ria.df, Land_use == "Forest_plantation"))

## Habitat breadth
ria_f_h.lm <- lmer(lnRR ~ Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = filter(ria.df, Land_use == "Forest_plantation"), REML = T)
test.f(ria_f_0.lm, ria_f_h.lm)
nrow(filter(ria.df, Land_use == "Forest_plantation"))


# Richness ----------------------------------------------------------------

# Cropland
rsr_c_0.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Cropland"), REML = T)

## Main
rsr_c_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Cropland"), REML = T)
test.f(rsr_c_0.lm, rsr_c_m.lm)
nrow(filter(rsr.df, Land_use == "Cropland"))

# Forest plantation
rsr_f_0.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Forest_plantation"), REML = T)

## Main
rsr_f_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Forest_plantation"), REML = T)
test.f(rsr_f_0.lm, rsr_f_m.lm)
nrow(filter(rsr.df, Land_use == "Forest_plantation"))

## Latitude
rsr_f_l.lm <- lmer(lnRR ~ Natural_elements + Latitude_abs + (1|Source_ID / Study_ID), weights = weight, data = filter(rsr.df, Land_use == "Forest_plantation"), REML = T)
test.f(rsr_f_0.lm, rsr_f_l.lm)
nrow(filter(rsr.df, Land_use == "Forest_plantation"))


# MSA ---------------------------------------------------------------------

# Cropland
msa_c_0.lm <- lmer(ltMSA ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Cropland"), REML = T)

## main
msa_c_m.lm <- lmer(ltMSA ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Cropland"), REML = T)
test.f(msa_c_0.lm, msa_c_m.lm)
nrow(filter(msa.df, Land_use == "Cropland"))

## Latitude
msa_c_l.lm <- lmer(ltMSA ~ Natural_elements + Latitude_abs + Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Cropland"), REML = T)
test.f(msa_c_0.lm, msa_c_l.lm)
nrow(filter(msa.df, Land_use == "Cropland"))


# Forest plantation
msa_f_0.lm <- lmer(ltMSA ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Forest_plantation"), REML = T)

## Main
msa_f_m.lm <- lmer(ltMSA ~ Diversification + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Forest_plantation"), REML = T)
test.f(msa_f_0.lm, msa_f_m.lm)
nrow(filter(msa.df, Land_use == "Forest_plantation"))

## Landscape context
msa_f_lc.lm <- lmer(ltMSA ~ Diversification + Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = filter(msa.df, Land_use == "Forest_plantation"), REML = T)
test.f(msa_f_0.lm, msa_f_lc.lm)
nrow(filter(msa.df, Land_use == "Forest_plantation"))